@@ -5,6 +5,7 @@
 
 #import "HeatbugModelSwarm.h"
 #import <simtools.h>
+#import <random.h>
 
 @implementation HeatbugModelSwarm
 
@@ -13,30 +14,35 @@
 // In theory we could just let other objects use Probes to read our state,
 // but message access is frequently more convenient.
 
--getHeatbugList {
+- getHeatbugList
+{
   return heatbugList;
 }
 
--getWorld {
+- getWorld
+{
   return world;
 }
 
--getHeat {
+- getHeat
+{
   return heat;
 }
 
 // This method isn't normally used, but is convenient when running probes:
 // it lets you easily clone a heatbug and drag it into the model.
 
--addHeatbug: (Heatbug *) bug {
+- addHeatbug: (Heatbug *)bug
+{
   [heatbugList addLast: bug];
   return self;
 }
 
 // createBegin: here we set up the default simulation parameters.
 
-+createBegin: (id) aZone {
-  HeatbugModelSwarm * obj;
++ createBegin: aZone
+{
+  HeatbugModelSwarm *obj;
   id <ProbeMap> probeMap;
 
   // First, call our superclass createBegin - the return value is the
@@ -82,6 +88,8 @@
   [probeMap addProbe: [probeLibrary getProbeForVariable: "minOutputHeat"
 				    inClass: [self class]]];
   [probeMap addProbe: [probeLibrary getProbeForVariable: "maxOutputHeat"
+				    inClass: [self class]]]; 
+  [probeMap addProbe: [probeLibrary getProbeForVariable: "evaporationRate"
 				    inClass: [self class]]];
   [probeMap addProbe: [probeLibrary getProbeForVariable: "randomMoveProbability"
 				    inClass: [self class]]];
@@ -106,14 +114,16 @@
 // to later. (In this example, this method does nothing at all and could
 // just be inherited. But it's here to show you a place to customize.)
 
--createEnd {
+- createEnd
+{
   return [super createEnd];
 }
 
 // Now it's time to build the model objects. We use various parameters
 // inside ourselves to choose how to create things.
 
--buildObjects {
+- buildObjects
+{
   int i;
 
   // allow our parent class to build anything.
@@ -152,47 +162,49 @@
 
   // Now a loop to create a bunch of heatbugs.
 
-  for (i = 0; i < numBugs; i++) {
-    Heatbug * hbug;
-    int idealTemp, outputHeat;
+  for (i = 0; i < numBugs; i++)
+    {
+      Heatbug * hbug;
+      int idealTemp, outputHeat;
+      
+      // Choose a random ideal temperature, output heat from the specified
+      // range (model parameters).
+      
+      //    idealTemp = [uniformRandom rMin: minIdealTemp Max: maxIdealTemp];
+      //    outputHeat = [uniformRandom rMin: minOutputHeat Max: maxOutputHeat];
+      
+      idealTemp = [uniformIntRand
+                    getIntegerWithMin: minIdealTemp withMax: maxIdealTemp];
+      outputHeat = [uniformIntRand
+                     getIntegerWithMin: minOutputHeat withMax: maxOutputHeat];
+      
+      
+      // Create the heatbug, set the creation time variables
+      
+      hbug = [Heatbug createBegin: [self getZone]];
+      [hbug setWorld: world Heat: heat];
+      hbug = [hbug createEnd];
+      
+      // Add the bug to the end of the list.
+      
+      [heatbugList addLast: hbug];
+      
+      // Now initialize the rest of the heatbug's state.
+      
+      [hbug setIdealTemperature: idealTemp];
+      [hbug setOutputHeat: outputHeat];
+      [hbug setRandomMoveProbability: randomMoveProbability];
+      
+      //    [hbug setX: [uniformRandom rMax: worldXSize]  // random position
+      //	  Y: [uniformRandom rMax: worldYSize]];
 
-    // Choose a random ideal temperature, output heat from the specified
-    // range (model parameters).
-
-//    idealTemp = [uniformRandom rMin: minIdealTemp Max: maxIdealTemp];
-//    outputHeat = [uniformRandom rMin: minOutputHeat Max: maxOutputHeat];
-
-    idealTemp = [uniformIntRand
-                  getIntegerWithMin: minIdealTemp withMax: maxIdealTemp];
-    outputHeat = [uniformIntRand
-                   getIntegerWithMin: minOutputHeat withMax: maxOutputHeat];
-
-
-    // Create the heatbug, set the creation time variables
-
-    hbug = [Heatbug createBegin: [self getZone]];
-    [hbug setWorld: world Heat: heat];
-    hbug = [hbug createEnd];
-
-    // Add the bug to the end of the list.
-
-    [heatbugList addLast: hbug];
-
-    // Now initialize the rest of the heatbug's state.
-
-    [hbug setIdealTemperature: idealTemp];
-    [hbug setOutputHeat: outputHeat];
-
-//    [hbug setX: [uniformRandom rMax: worldXSize]  // random position
-//	  Y: [uniformRandom rMax: worldYSize]];
-
-    [hbug setX: [uniformIntRand
-                  getIntegerWithMin: 0L
-                  withMax: (worldXSize-1)]  // random position
-          Y: [uniformIntRand getIntegerWithMin: 0L withMax: (worldYSize-1)]];
-  }
+      [hbug setX: [uniformIntRand
+                    getIntegerWithMin: 0L
+                    withMax: (worldXSize-1)]  // random position
+            Y: [uniformIntRand getIntegerWithMin: 0L withMax: (worldYSize-1)]];
+    }
   [world setOverwriteWarnings: 1];		  // ok, done cheating.
-
+  
   return self;
 }
 
@@ -200,8 +212,8 @@
 // that define the simulation of time in the mode. The core is an
 // actionGroup that has a list of actions. That's then put in a Schedule.
 
--buildActions {
-
+- buildActions
+{
   [super buildActions];
   
   // Create the list of simulation actions. We put these in an action
@@ -241,8 +253,8 @@
 // we're being started in - typically, this model is run as a subswarm
 // of an observer swarm.
 
--activateIn: (id) swarmContext {
-
+- activateIn: swarmContext
+{
   // First, activate ourselves via the superclass activateIn: method.
   // Just pass along the context: the activity library does the right thing.
 
