@@ -6,8 +6,9 @@
 #import "HeatbugObserverSwarm.h"
 #import "HeatbugModelSwarm.h"
 #import <collections.h>
-#import <swarmobject.h>
+#import <objectbase.h>
 #import <analysis.h>
+#import <gui.h>
 
 @implementation HeatbugObserverSwarm
 
@@ -114,7 +115,7 @@
   // First, create a colormap: this is a global resource, the information
   // here is used by lots of different objects.
 
-  colormap = [XColormap create: [self getZone]];
+  colormap = [Colormap create: [self getZone]];
 
   // Colours [0,64) are assigned to the range Red [0, 1), for heat display.
 
@@ -151,7 +152,7 @@
   // display arbitrary 2d value arrays on a given Raster widget.
 
   heatDisplay = [Value2dDisplay createBegin: [self getZone]];
-  [heatDisplay setDisplayWidget: worldRaster Colormap: colormap];
+  [heatDisplay setDisplayWidget: worldRaster colormap: colormap];
   [heatDisplay setDiscrete2dToDisplay: [heatbugModelSwarm getHeat]];
   [heatDisplay setDisplayMappingM: 512 C: 0];	  // turn [0,32768) -> [0,64)
   heatDisplay = [heatDisplay createEnd];
@@ -169,17 +170,19 @@
   // Also, tell the world raster to send mouse clicks to the heatbugDisplay
   // this allows the user to right-click on the display to probe the bugs.
 
-  [worldRaster setButton: ButtonRight Client: heatbugDisplay Message: M(makeProbeAtX:Y:)];
+  [worldRaster setButton: ButtonRight
+               Client: heatbugDisplay
+               Message: M(makeProbeAtX:Y:)];
 
   // Create the graph widget to display unhappiness.
 
   unhappyGraph = [EZGraph createBegin: [self getZone]];
-  [unhappyGraph enableDestroyNotification: self
-                notificationMethod: @selector (_unhappyGraphDeath_:)];
   SET_WINDOW_GEOMETRY_RECORD_NAME (unhappyGraph);
   [unhappyGraph setTitle: "Unhappiness of bugs vs. time"];
   [unhappyGraph setAxisLabelsX: "time" Y: "unhappiness"];
   unhappyGraph = [unhappyGraph createEnd];
+  [unhappyGraph enableDestroyNotification: self
+                notificationMethod: @selector (_unhappyGraphDeath_:)];
 
   [unhappyGraph createAverageSequence: "unhappiness"
                          withFeedFrom: [heatbugModelSwarm getHeatbugList] 
