@@ -3,7 +3,8 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <simtools.h>                // ... for initSwarm() and swarmGUIMode
+#import <simtools.h>     // initSwarm () and swarmGUIMode
+#import <simtoolsgui.h>  // GUISwarm
 #import "HeatbugObserverSwarm.h"
 #import "HeatbugBatchSwarm.h"
 
@@ -12,11 +13,12 @@
 // Swarm, let it build and activate, and set it to running.
 
 int
-main(int argc, char ** argv) {
-  id theTopLevelSwarm ;
+main (int argc, const char **argv)
+{
+  id theTopLevelSwarm;
 
   // Swarm initialization: all Swarm apps must call this first.
-  initSwarm(argc, argv);
+  initSwarm (argc, argv);
 
   // swarmGUIMode is set in initSwarm(). It's set to be 1 if you
   // typed heatbugs -batchmode. Otherwise, it's set to 0.
