@@ -3,7 +3,7 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <simtools.h>
+#import <random.h>
 #import "PplModelSwarm.h"
 
 // Implementation of the model for ppl.
