@@ -10,10 +10,11 @@
 #import "PplObserverSwarm.h"
 
 int
-main(int argc, char ** argv) {
-  PplObserverSwarm * observerSwarm;
+main (int argc, const char **argv)
+{
+  PplObserverSwarm *observerSwarm;
 
-  initSwarm(argc, argv);
+  initSwarm (argc, argv);
 
   observerSwarm = [PplObserverSwarm create: globalZone];
   [observerSwarm buildObjects];
