@@ -3,7 +3,7 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <simtools.h>
+#import <random.h>
 #import "PplModelSwarm.h"
 
 // Implementation of the model for ppl.
@@ -15,9 +15,9 @@
   return counter;
 }
 
-+ createBegin: (id) aZone
++ createBegin: aZone
 {
-  PplModelSwarm * obj;
+  PplModelSwarm *obj;
   id <ProbeMap> probeMap;
 
   obj = [super createBegin: aZone];
@@ -66,67 +66,57 @@
   pplList = [List create: [self getZone]];
 
   // build the ppl
-  for (inci = 0; inci < numPpl; inci++){
-    Person * person;
-    id name;
-    float topics[2];
-    int namesize;
+  for (inci = 0; inci < numPpl; inci++)
+    {
+      Person *person;
+      id name;
+      float topics[2];
+      int namesize;
+      char temp_char[2];
 
-    // Linux Note!  For some reason, unless this is a full 32-bit
-    //        variable, control characters get mixed up in 
-    //        the chars as they are added to the name
-    //        I suspect that when the String object gets its
-    //        zone, that zone is not cleared.  Since everything
-    //        is added to the string by address and chars are 8-bits
-    //        the setC and appendC have to be smart enough to throw
-    //        away the part of the word that isn't relevant.
-    //        Must be an endian problem.
-#ifdef linux
-    int temp_char; 
-#else
-    char temp_char;
-#endif
-
-    // allocate memory for a temporary person
-    person = [Person createBegin: [self getZone]];
-
-    // come up with a name
-    namesize = [uniformIntRand getIntegerWithMin: 2L withMax: 4L];
-
-    // initialize and create the name
-    temp_char = [uniformIntRand getIntegerWithMin: 'A' withMax:'Z'];
-    name = [String createBegin: [person getZone] ];
-    [name setC: (char *) &temp_char];
-    name = [name createEnd];
-
-    // then finish the name
-    for (incj = 1; incj <= namesize; incj++) {
-      temp_char = [uniformIntRand getIntegerWithMin:'a' withMax:'z'];
-      [name appendC: (char *) &temp_char];
+      // allocate memory for a temporary person
+      person = [Person createBegin: [self getZone]];
+      
+      // come up with a name
+      namesize = [uniformIntRand getIntegerWithMin: 2L withMax: 4L];
+      
+      // initialize and create the name
+      temp_char[0] = [uniformIntRand getIntegerWithMin: 'A' withMax: 'Z'];
+      temp_char[1] = '\0';
+      name = [String createBegin: [person getZone]];
+      [name setC: temp_char];
+      name = [name createEnd];
+      
+      // then finish the name
+      for (incj = 1; incj <= namesize; incj++)
+        {
+          temp_char[0] = [uniformIntRand getIntegerWithMin: 'a' withMax: 'z'];
+          [name appendC: (char *) &temp_char];
+        }
+      
+      // the null topic is how undesirable communication is for this person
+      topics[null] = 0.0;
+      // hello is the only thing to say for now
+      topics[hello] = 1.0;
+      // tell the person what her comm numbers are
+      [person setPerson: name Topic_array: topics];
+      // tell the person where she is
+      [person setWorld: pplList Party: self];
+      
+      // re-allocate the person and finish the create phase
+      person = [person createEnd];
+      
+      // add the person to the list of people
+      [pplList addLast: person];
+      
     }
-
-    // the null topic is how undesirable communication is for this person
-    topics[null] = 0.0;
-    // hello is the only thing to say for now
-    topics[hello] = 1.0;
-    // tell the person what her comm numbers are
-    [person setPerson: name Topic_array: topics];
-    // tell the person where she is
-    [person setWorld: pplList Party: self];
-
-    // re-allocate the person and finish the create phase
-    person = [person createEnd];
-
-    // add the person to the list of people
-    [pplList addLast: person];
-
-  }
   return self;
 }
 
--buildActions {
+- buildActions
+{
   [super buildActions];
-
+  
   // create an action group to delineate the events
   modelActions = [ActionGroup create: [self getZone]];
   // Create an action to send a message to the counter every cycle
@@ -150,8 +140,8 @@
   return self;
 }
 
--activateIn: (id) swarmContext {
-
+- activateIn: swarmContext
+{
   // the modelswarm will have a number of people talking
   // initialize it right before activating the model swarm
   numberPplStillTalking = numPpl;
@@ -165,13 +155,15 @@
 }
 
 // the objects will call this when they're done talking
--ImFinished {
+- ImFinished
+{
   numberPplStillTalking--;
   return self;
 }
 
 // the observer will call this to find out when to quit
-- (int) getNumberPplStillTalking {
+- (int) getNumberPplStillTalking
+{
   return numberPplStillTalking;
 }
 @end
