@@ -4,7 +4,8 @@
 // See file LICENSE for details and terms of copying.
 
 #import "PplObserverSwarm.h"
-#import <simtools/ActiveGraph.h>
+#import <simtoolsgui/ActiveGraph.h>
+#import <gui.h>
 
 // implementation of sample graphical interface for models.
 @implementation PplObserverSwarm
@@ -33,11 +34,13 @@
 }
 
 // MODIFY: possible creation finalization here
--createEnd {
+- createEnd
+{
   return [super createEnd];
 }
 
--buildObjects {
+- buildObjects
+{
   id modelZone;
 
   [super buildObjects];
@@ -55,7 +58,7 @@
   CREATE_PROBE_DISPLAY (self);
 
   // set the control panel state
-  [controlPanel waitForControlEvent];
+  [actionCache waitForControlEvent];
   // test to see if the "quit" button was hit
   if ([controlPanel getState] == ControlStateQuit)
     return self;
@@ -69,9 +72,9 @@
 
   // creat a graph of numberPplStillTalking using the BLT
   // graph straight out of the library
-  pplLeftGraph = [BLTGraph create: [self getZone]];
-  [pplLeftGraph title: "Number of Ppl Still Talking"];
-  [pplLeftGraph axisLabelsX: "Cycle" Y: "Number Left"];
+  pplLeftGraph = [Graph create: [self getZone]];
+  [pplLeftGraph setTitle: "Number of Ppl Still Talking"];
+  [pplLeftGraph setAxisLabelsX: "Cycle" Y: "Number Left"];
   [pplLeftGraph setWidth: 400 Height: 250];
   [pplLeftGraph pack];
   [pplLeftGraph setScaleModeX: 1 Y: 0];
@@ -103,13 +106,13 @@
   // update the counter
   [displayActions createActionTo: observedCounter     message: M(print)];
   // update the graph
-  [displayActions createActionTo: pplLeftGrapher        message: M(step)];
+  [displayActions createActionTo: pplLeftGrapher      message: M(step)];
   // check to see if everybody's done talking
   [displayActions createActionTo: self                message: M(checkToStop)];
   // update the probes
   [displayActions createActionTo: probeDisplayManager message: M(update)];
   // check the controlpanel for clicks
-  [displayActions createActionTo: actionCache        message: M(doTkEvents)];
+  [displayActions createActionTo: actionCache         message: M(doTkEvents)];
 
   // then actually schedule the display actions
   displaySchedule = [Schedule createBegin: [self getZone]];
@@ -120,10 +123,11 @@
   return self;
 }  
 
--activateIn: (id) swarmContext {
+- activateIn: swarmContext
+{
   // put self (observer swarm) on the schedule of the GUI swarm
   [super activateIn: swarmContext];
-
+  
   // start the activity for the model swarm
   [pplModelSwarm activateIn: self];
   // start the display schedule
@@ -135,12 +139,14 @@
 // this method queries the pplModelSwarm to find out if everybody
 // has sent the ImFinished message to the modelswarm.  If so,
 // then stop the sim because nobody's talking.
--checkToStop {
-  if ([pplModelSwarm getNumberPplStillTalking] <= 0) {
-    (void) printf("Party's over!  You don't have to go home;"
-		  "  but you can't stay here.\n");
-    [controlPanel setStateStopped];
-  }
+- checkToStop
+{
+  if ([pplModelSwarm getNumberPplStillTalking] <= 0)
+    {
+      (void)printf ("Party's over!  You don't have to go home;"
+                    "  but you can't stay here.\n");
+      [controlPanel setStateStopped];
+    }
   return self;
 }
 
