@@ -9,7 +9,7 @@
 
 // include the space declarations
 #import <space.h>
-#import <tkobjc/Raster.h>
+#import <gui.h>
 #import <collections/String.h>
 
 // this is the space agent superclass
@@ -39,8 +39,6 @@ typedef enum {
 
   Person *target;
   int approachingTarget;
-
-
 }
 
 // move one time step forward
