@@ -2,16 +2,15 @@
 // This library is distributed without any warranty; without even the
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
-
 // This is the method definitions file for the Person agents.
 
-// include simtools so we can use the random number library
-#import <simtools.h>
 // include person header so that everything will be defined
 #import "Person.h"
 #import "PplModelSwarm.h"
 #define VNSet 4
 
+#import <random.h>
+
 @implementation Person
 
 - step
@@ -222,7 +221,7 @@
 
 // this method sends a message to the raster telling it to place
 //   me on it with my color
-- drawSelfOn: (Raster *)rast
+- drawSelfOn: (id <Raster>)rast
 {
   [rast drawPointX: x Y: y Color: myColor];
   return self;
