@@ -4,7 +4,7 @@
 // See file LICENSE for details and terms of copying.
 
 #import <space.h>
-#import <swarmobject.h>
+#import <objectbase.h>
 #import "Counter.h"
 #import "Person.h"
 // include the neighborhood object 
