@@ -3,12 +3,12 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-// peculiar to gcc when including some of the header files
-#define __USE_FIXED_PROTOTYPES__
-#include <math.h>
-#import <simtools.h>
 #import "PplModelSwarm.h"
 
+#import <random.h>
+
+#include <math.h>
+
 // declare the neighborhood to use
 VNneighbor * vnneighbor;
 
@@ -162,7 +162,7 @@ VNneighbor * vnneighbor;
       topics[hello] = 1.0;
 
       // generate a color for her
-      color = (Color) [uniformUnsRand getUnsignedWithMin: 1L withMax: 124L];
+      color = (Color)[uniformUnsRand getUnsignedWithMin: 1L withMax: 124L];
       [person setPersonColor: color];
 
       // tell the person what her comm numbers are
