@@ -3,13 +3,14 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <objectbase.h>
-#import <simtools/GUISwarm.h>
+#import <simtoolsgui/GUISwarm.h>
+#import <simtoolsgui.h>
 #import <analysis.h>
+#import <gui.h>
 #import "PplModelSwarm.h"
 
 // Sample graphical interface swarm for models.
-@interface PplObserverSwarm : GUISwarm
+@interface PplObserverSwarm: GUISwarm
 {
   int displayFrequency;
 
@@ -17,31 +18,31 @@
   id displaySchedule;
 
   // add the modelswarm to the observer swarm
-  PplModelSwarm * pplModelSwarm;
+  PplModelSwarm *pplModelSwarm;
   // add the counter to the observer swarm
-  Counter * observedCounter;
+  Counter *observedCounter;
 
   // add the numberPplStillTalking graph to obs swarm
-  BLTGraph * pplLeftGraph;
-  GraphElement * numberLeft;
-  ActiveGraph  * pplLeftGrapher;
+  id <Graph> pplLeftGraph;
+  id <GraphElement> numberLeft;
+  id <ActiveGraph> pplLeftGrapher;
 
   // add the number of friends averager
-  EZGraph * avgFriendGraph;
+  EZGraph *avgFriendGraph;
 
   // add the space viewer objects
-  XColormap * colormap;
-  ZoomRaster * worldRaster;
-  Object2dDisplay * pplDisplay;
+  id <Colormap> colormap;
+  id <ZoomRaster> worldRaster;
+  Object2dDisplay *pplDisplay;
 }
 
-+createBegin: (id) aZone;
--createEnd;
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
++ createBegin: aZone;
+- createEnd;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 // checks to see if everybody's done talking
--checkToStop;
+- checkToStop;
 
 @end
