@@ -3,11 +3,11 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-// peculiar to some gcc function prototypes
-#define __USE_FIXED_PROTOTYPES__
-#include <math.h>
 #import "PplObserverSwarm.h"
-#import <simtools/ActiveGraph.h>
+#import <simtoolsgui.h>
+#import <gui.h>
+
+#include <math.h>
 
 // implementation of sample graphical interface for models.
 @implementation PplObserverSwarm
@@ -62,7 +62,7 @@
   CREATE_PROBE_DISPLAY (self);
 
   // set the control panel state
-  [controlPanel waitForControlEvent];
+  [actionCache waitForControlEvent];
   // test to see if the "quit" button was hit
   if ([controlPanel getState] == ControlStateQuit)
     return self;
@@ -74,11 +74,11 @@
   observedCounter = [pplModelSwarm getCounter];
 
 
-  // creat a graph of numberPplStillTalking using the BLT
-  // graph straight out of the library
-  pplLeftGraph = [BLTGraph create: [self getZone]];
-  [pplLeftGraph title: "Number of Ppl Still Talking"];
-  [pplLeftGraph axisLabelsX: "Cycle" Y: "Number Left"];
+  // Creat a graph of numberPplStillTalking using the Graph
+  // straight out of the library.
+  pplLeftGraph = [Graph create: [self getZone]];
+  [pplLeftGraph setTitle: "Number of Ppl Still Talking"];
+  [pplLeftGraph setAxisLabelsX: "Cycle" Y: "Number Left"];
   [pplLeftGraph setWidth: 400 Height: 250];
   [pplLeftGraph pack];
   [pplLeftGraph setScaleModeX: 1 Y: 0];
@@ -106,7 +106,7 @@
 
   // Now draw the space
 
-  colormap = [XColormap create: [self getZone]];
+  colormap = [Colormap create: [self getZone]];
   // set up the colormap
   for (inci = 0; inci < 125; inci++)
     {
@@ -141,8 +141,9 @@
 
   // Also, tell the world raster to send mouse clicks to the pplDisplay
   // this allows the user to right-click on the display to probe the bugs.
-  [worldRaster setButton: ButtonRight Client: pplDisplay Message: M(makeProbeAtX:Y:)];
-
+  [worldRaster setButton: ButtonRight
+               Client: pplDisplay
+               Message: M(makeProbeAtX:Y:)];
 
   return self;
 }  
