@@ -3,9 +3,10 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <swarmobject.h>
+#import <objectbase.h>
 
-@interface MarketModelSwarm : Swarm {
+@interface MarketModelSwarm: Swarm
+{
   int numPredictors;
   double accuracyUpdateRate;
   double discountRate;
@@ -17,14 +18,14 @@
   id aMarket;
 }
 
--(double) getPrice;
--(double) getDividend;
--(double) getFundamental;
--(int *) getPredictorUse;
+- (double)getPrice;
+- (double)getDividend;
+- (double)getFundamental;
+- (int *)getPredictorUse;
 
-+createBegin: (id) aZone;
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
++ createBegin: aZone;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 @end
