@@ -3,28 +3,30 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <swarmobject.h>
-#import <simtools/GUISwarm.h>
 #import "MarketModelSwarm.h"
+#import <simtoolsgui/GUISwarm.h>
+#import <simtoolsgui.h>
+#import <gui.h>
 
 // Sample graphical interface swarm for models.
-@interface MarketObserverSwarm : GUISwarm {
+@interface MarketObserverSwarm: GUISwarm
+{
   int displayFrequency;
 
   id displayActions;
   id displaySchedule;
 
-  MarketModelSwarm * marketModelSwarm;
+  MarketModelSwarm *marketModelSwarm;
 
-  BLTGraph *priceGraph;
-  GraphElement *priceElement, *dividendElement, *fundamentalElement;
-  ActiveGraph *priceGrapher, *dividendGrapher, *fundamentalGrapher;
-  Histo *useHisto;
+  id <Graph> priceGraph;
+  id <GraphElement> priceElement, dividendElement, fundamentalElement;
+  id <ActiveGraph> priceGrapher, dividendGrapher, fundamentalGrapher;
+  id <Histogram> useHisto;
 }
 
-+createBegin: (id) aZone;
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
++ createBegin: aZone;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 @end
