@@ -7,7 +7,7 @@
 #import "define.h"
 #import "extern.h"
 #import "MarketObserverSwarm.h"
-#import <simtools/ActiveGraph.h>
+#import <gui.h>
 
 static const char *predictorColors[] = {
   "red", "orange", "yellow", "green", "blue", "purple", "grey50", "black",
@@ -58,7 +58,7 @@ static unsigned numPredictorsToShow = 7;
   CREATE_ARCHIVED_PROBE_DISPLAY (marketModelSwarm);
   CREATE_ARCHIVED_PROBE_DISPLAY (self);
 
-  [controlPanel waitForControlEvent];
+  [actionCache waitForControlEvent];
   if ([controlPanel getState] == ControlStateQuit)
     return self;
 
@@ -68,11 +68,11 @@ static unsigned numPredictorsToShow = 7;
   pr_text = 0;
   
   // create graph for price of commodity
-  priceGraph = [BLTGraph createBegin: globalZone];
+  priceGraph = [Graph createBegin: globalZone];
   SET_WINDOW_GEOMETRY_RECORD_NAME (priceGraph);
   priceGraph = [priceGraph createEnd];
-  [priceGraph title: "Price of commodity vs. time"];
-  [priceGraph axisLabelsX: "time" Y: "price"];
+  [priceGraph setTitle: "Price of commodity vs. time"];
+  [priceGraph setAxisLabelsX: "time" Y: "price"];
   [priceGraph setWidth: 400 Height: 250];
   [priceGraph pack];
   [priceGraph setScaleModeX: 1 Y: 0];
@@ -102,7 +102,7 @@ static unsigned numPredictorsToShow = 7;
   [fundamentalGrapher setProbedSelector: M(getFundamental)];
   fundamentalGrapher = [fundamentalGrapher createEnd];
   
-  useHisto = [Histo createBegin: globalZone];
+  useHisto = [Histogram createBegin: globalZone];
   SET_WINDOW_GEOMETRY_RECORD_NAME (useHisto);
   useHisto = [useHisto createEnd];
 
@@ -113,8 +113,8 @@ static unsigned numPredictorsToShow = 7;
   [useHisto setNumPoints: numPredictorsToShow
 	    Labels: pred
 	    Colors: predictorColors];
-  [useHisto title: "Usage of predictors"];
-  [useHisto axisLabelsX: "predictor index" Y: "usage of predictor"];
+  [useHisto setTitle: "Usage of predictors"];
+  [useHisto setAxisLabelsX: "predictor index" Y: "usage of predictor"];
   [useHisto pack];
   
   return self;
@@ -155,7 +155,7 @@ static unsigned numPredictorsToShow = 7;
 - updateHisto
 {
   if (useHisto)
-    [useHisto drawHistoWithInt: [marketModelSwarm getPredictorUse]];
+    [useHisto drawHistogramWithInt: [marketModelSwarm getPredictorUse]];
 
   return self;
 }
