@@ -5,7 +5,7 @@
 
 #include "define.h"
 #include "extern.h"
-#import <simtools.h>
+#import <random.h>
 
 void Initiate_agents(hombre agent[]) {
   /* Assigns predictors to be monitored by
