@@ -5,9 +5,9 @@
 
 #import "MousetrapObserverSwarm.h"
 #import "MousetrapModelSwarm.h"
-#import <collections.h>
-#import <swarmobject.h>
 #import <analysis.h>
+#import <simtoolsgui.h>
+#import <gui.h>
 
 // The MousetrapObserverSwarm is the top-level swarm that
 // watches and reports on what's happening in the 
@@ -125,7 +125,7 @@
   // chance to fill in parameters before the simulation runs
   // If the user hit the quit button here, we quit.
 
-  [controlPanel waitForControlEvent];
+  [actionCache waitForControlEvent];
   if ([controlPanel getState] == ControlStateQuit)
     return self;
 
@@ -138,7 +138,7 @@
 
   // create a colormap
 
-  colormap = [XColormap create: globalZone];
+  colormap = [Colormap create: globalZone];
   [colormap setColor: 1 ToGrey: 0.3];
   [colormap setColor: 2 ToName: "red"];
 
