@@ -3,26 +3,26 @@
 // implied warranty of merchantability or fitness for a particular purpose.
 // See file LICENSE for details and terms of copying.
 
-#import <swarmobject.h>
-#import <simtools/GUISwarm.h>
+#import <simtoolsgui/GUISwarm.h>
 #import "TemplateModelSwarm.h"
 
 // Sample graphical interface swarm for models.
-@interface TemplateObserverSwarm : GUISwarm {
+@interface TemplateObserverSwarm: GUISwarm
+{
   int displayFrequency;
 
   id displayActions;
   id displaySchedule;
 
   // MODIFY: add display objects
-  TemplateModelSwarm * templateModelSwarm;
-  Counter * observedCounter;
+  TemplateModelSwarm *templateModelSwarm;
+  Counter *observedCounter;
 }
 
-+createBegin: (id) aZone;
--createEnd;
--buildObjects;
--buildActions;
--activateIn: (id) swarmContext;
++ createBegin: aZone;
+- createEnd;
+- buildObjects;
+- buildActions;
+- activateIn: swarmContext;
 
 @end
