@@ -4,11 +4,12 @@
 // See file LICENSE for details and terms of copying.
 
 #import "TemplateObserverSwarm.h"
+#import <simtoolsgui.h>
 
 // implementation of sample graphical interface for models.
 @implementation TemplateObserverSwarm
 
-+createBegin: aZone
++ createBegin: aZone
 {
   TemplateObserverSwarm * obj;
   id <ProbeMap> probeMap;
@@ -32,11 +33,13 @@
 }
 
 // MODIFY: possible creation finalization here
--createEnd {
+- createEnd
+{
   return [super createEnd];
 }
 
--buildObjects {
+- buildObjects
+{
   id modelZone;
 
   [super buildObjects];
@@ -47,7 +50,7 @@
   CREATE_PROBE_DISPLAY (templateModelSwarm);
   CREATE_PROBE_DISPLAY (self);
 
-  [controlPanel waitForControlEvent];
+  [actionCache waitForControlEvent];
   if ([controlPanel getState] == ControlStateQuit)
     return self;
 
@@ -79,7 +82,8 @@
   return self;
 }  
 
--activateIn: (id) swarmContext {
+- activateIn: swarmContext
+{
   [super activateIn: swarmContext];
 
   [templateModelSwarm activateIn: self];
